 1] // Parse the command line                                           

    getpars ( argc, argv, sdeffile, &Autosync, );

 2] // Read scan definition from scandef file

    sid = read_scandef ( sdeffile,  );

 3] //  Initialize for MF processing

    X = create_gmfsetup ( sid,  );

    if ( Autosync )
    {
 4]     // Synchronize scan start position against an EISCAT 
        // integration period boundary if there are "gaps",
        // else synchronize only to next cycle boundary.

        synchronize ( sid, );
    }

 5] // Open input gstream for scanning

    tau_ns = (long) (sid->tau) * (double)1000;
    gid = gopen ( sid->file1, "r", 
                       sid_time1, sid->offs, , tau_ns, ); 

    if ( ! Testmode )
    {
 6]     // Open a hitlist file, and write current scandef to
        // it's beginning.

        hid = fopen ( hitfile, "w" );
        print_SCANDEF ( hid, sid );
    }

 7] // An infinite scanning loop. Each pass is one scan. 
    // The scan goes through all the requested ranges r
    // and produces the profile, Ratio(r), which
    // at end of the loop is inspected by a threshold
    // detector.

    gates_to_do = X->nshifts;
   	
    while ( 1 )     // SCAN LOOP //
    {
 8]    // Check that TX rising edge is located as expected

        if ( Synccheck )
            tx_pos = checksync ( gid, -2, +2, );
 
 9]     // Get data for next integration. "Rawlen" is the
        // length of the integration in integer number of
        // cycles. An addition, we need to read some
        // "extra" points if we search targets beyond the
        // first matching window.

        gread ( gid, X->rawlen + X->nextra, raw->realp,
                     raw->imagp, msg );
                   
        if ( *msg ) 
            break;   // Typically exit due to the end
                     // of input gstream. 

10]     // Skip over "nskip" points, positioning us 
        // ready for next integration.
        
        gseek ( gid, -(X->nextra) + X->nskip, );

11]     // Estimate TX energy and mean background noise
        // power for this scan.

        tx_and_noise ( X, raw, noiseshift, &noisepower,
                          &txenergy ); 
                          
        normalizer = 1.0 / ( noisepower * txenergy );

12]     // In the scan, we compute X->nshifts range gates
        // r. We compute X->blocksize range gates by a
        // single call to the gmf() or fastgmf(). The next
        // loop produces Ratio for the required ranges,
        // each pass handling one block of ranges.

        while ( gates_to_do > 0 )	// BLOCK LOOP //
        {
            if ( gates_to_do >= X->blocksize )
                ngates = X->blocksize;
            else
                ngates = gates_to_do;

13]         // Call the appropriate MF routine to
            // compute MF velocity slices, each
            // of length X->gmflen,
            //      v --> MF(r, v)^2,
            // for the ngates range gates of the
            // current block.

            if ( X->usefastgmf )
                fastgmf ( X, raw, ngates, gate0, gmf2 );
            else
                gmf ( X, raw, ngates, gate0, gmf2 );

14]         // Compute Ratio(r_j) = 
            //   max_v { sqrt [ MF^2 / (P_noise * W_tx) ] }
                        
            for ( gate = 0; gate < ngates; gate++ )
            {
                g2max = floatmax ( gmf2[gate], X->gmflen,
                                               &k_max );
                *rat++ = sqrt ( g2max * normalizer );
            }

            gate0 += ngates;
            gates_to_do -= ngates;

        }// END OF BLOCK LOOP

15]     // Now we have all the range gates of the scan
        // ready. Do threshold detection.

        if ( Dedector ( ratio, X, &RatMax,, &gMax ) > 0 ) 
        {
16]         // For hit scans we compute also a velocity
            // estimate. To get it, we need to
            // re-generate the velocity slice that
            // goes though the hit's range gate.

            if ( X->usefastgmf )
                fastgmf ( X, raw, 1, gMax, gmf2 );
            else
                gmf_1 ( X, raw, 1, gMax, gmf2 );

            g2max = floatmax ( gmf2[0], X->gmflen, &kMax );

            Range = gate_to_range ( X, gMax );
            Velocity = k_to_veloc ( X, kMax );

            hit = 1;
            hitcount++;
        } 
        else 
        {
            Range = gate_to_range ( X, gMax );
            hit = 0;
        }           
        
        if ( ! Testmode )
        {
17]         // Optionally, save to matlab .mat files 
            //   - a piece of rawdata, 
            //   - the Ratio(R),
            //   - the velocity slice of the MF through
            //     the maximizing R. 
        }
        
18]     // Report statistics from the scan, 
        // report and save the hit if any.

        save_hit ( hid, hit, ratMax, Range, Velocity,,,,);
        
19] } // END OF SCAN LOOP
    
